@@ -4,7 +4,8 @@ from . import __title__
 
 from .app_settings import (
     AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS,
-    AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES
+    AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES,
+    AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS
 )
 
 
@@ -14,7 +15,8 @@ def index(request):
     context = {
         'title': __title__,
         'additionalPingTargets': AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS,
-        'additionalFleetTypes': AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES
+        'additionalFleetTypes': AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES,
+        'additionalPingWebhooks': AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS
     }
 
     return render(request, 'discordpingformatter/index.html', context)
